/**
* Utility lib for the IsOn24 app
*/
import logger from "../logger.js";

export function logInitInfo() {
  // console.log(`dotenv config: ${process.env.host} | ${process.env.database}`);
  logger.info(`dotenv config: ${process.env.host} | ${process.env.database}`); 
};

export function logObject(obj, level) {
  if(!level) level = 3;
  logger.debug(`Object: ${JSON.stringify(obj)}`);
};

export function isValidPhoneNumber(str) {
  let num = filterPhoneNumberInput(str);
  if (num.length === 10) {
    return true;
  }
  return false;
};

/**
* @param {*} str 
* @returns 
*/
export function filterNumberInput(str) {
  if (isEmptyString(str)) {
    return new String("");
  }
  // Make sure to convert to string
  str = String(str);
  // console.log(str);
  const regex = /[^0-9]/g;
  let num = str.replace(regex, '');

  if (isEmptyString(num)) {
    return new String("");
  }
  // console.log(str + ' -> ' + num);
  return num;
}
export function formatPhoneNumberInput(str) {
  let num = filterNumberInput(str);
  if (num.length === 10) {
    return formatPhoneNumber(num);
  }
  return num;
}

export function formatPhoneNumber(str) {
  //Filter only numbers from the input
  let cleaned = ('' + str).replace(/\D/g, '');
  
  //Check if the input is of correct
  let match = cleaned.match(/^(1|)?(\d{3})(\d{3})(\d{4})$/);
  
  if (match) {
    //Remove the matched extension code
    //Change this to format for any country code.
    let intlCode = (match[1] ? '+1 ' : '')
    return [intlCode, '(', match[2], ') ', match[3], '-', match[4]].join('')
  }
  
  return null;
}

/**
* returns a 10-digit-only string for a given phone number
* +14081111234 -> 4081111234
* (408) 123-4567 
* 
* @param {*} str 
* @returns 
*/
export function filterPhoneNumberInput(str) {
  let pnum = filterNumberInput(str);
  if(pnum.length > 10) {
    return pnum.substring( (pnum.length - 10));
  }
  return pnum;
}

export function getValidString(str) {
  if (str === null) {
    return '';
  }
  if (typeof str === 'undefined') {
    return '';
  }
  if (str === '') {
    return '';
  }
  return str;
}

export function isBlankString(str) {
  return isEmptyString(str);
}

export function isEmptyString(str) {
  if(!str) {
    return true;
  }
  let strObj = new String( String(str)  );
  if(strObj.trim().length > 0) {
    return false;
  }

  return true;
}

export function isNumberString(str) {
  return !(Number.isNaN(parseInt(str)));
}

export function isRecordingUrl(str) {
  const regex1 = new RegExp('https://ison24.com/rec/.*/Recordings/RE*');
  
  return ( regex1.test(str) );
}

/**
* 
* @param {*} tsStr 
* @returns a formatted timestamp like 'Sat, Dec 3, 10:47 am'
*/
export function getTSFormated(tsStr) {
  const tsFormat = { weekday: 'short', month: 'short', day: 'numeric', hour: 'numeric', minute: 'numeric' };
  return (new Date(tsStr)).toLocaleString('en-US', tsFormat)
}

export function getDateFormated(myDate, tz_str) {
  const tsFormat = { weekday: 'short', month: 'short', day: 'numeric', hour: 'numeric', minute: 'numeric', timeZone: tz_str };
  return myDate.toLocaleString('en-US', tsFormat)
}

/**
* 
* @param {*} tsStr 
* @returns Parses a string containing a date, and returns the number of milliseconds between that date and midnight, January 1, 1970.
*/
export function getTSMillis(tsStr) {
  return Date.parse(tsStr);
}
